summary refs log tree commit diff
path: root/pkgs
diff options
context:
space:
mode:
authortoonn <toonn@toonn.io>2023-10-19 23:54:32 +0200
committerGitHub <noreply@github.com>2023-10-19 23:54:32 +0200
commitcad1b2525d506ce75b9e3de3343a63722f2063e9 (patch)
tree47bc846c4bfaa08a88cf4ee3b63b700a12360efc /pkgs
parentd7d8f296e72931c51cdbae9009b469da33dd9564 (diff)
parent9ed7bfe46bf193e55a6fd8ae89dfe54b4dca2c18 (diff)
downloadnixpkgs-cad1b2525d506ce75b9e3de3343a63722f2063e9.tar
nixpkgs-cad1b2525d506ce75b9e3de3343a63722f2063e9.tar.gz
nixpkgs-cad1b2525d506ce75b9e3de3343a63722f2063e9.tar.bz2
nixpkgs-cad1b2525d506ce75b9e3de3343a63722f2063e9.tar.lz
nixpkgs-cad1b2525d506ce75b9e3de3343a63722f2063e9.tar.xz
nixpkgs-cad1b2525d506ce75b9e3de3343a63722f2063e9.tar.zst
nixpkgs-cad1b2525d506ce75b9e3de3343a63722f2063e9.zip
Merge pull request #241692 from reckenrode/darwin-llvm16-update
llvmPackages: 11 -> 16 on Darwin and Linux
Diffstat (limited to 'pkgs')
-rw-r--r--pkgs/top-level/all-packages.nix4
1 files changed, 2 insertions, 2 deletions
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index 493b2d0f807..ba694d92b3f 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -16672,10 +16672,10 @@ with pkgs;
     # This returns the minimum supported version for the platform. The
     # assumption is that or any later version is good.
     choose = platform:
       /**/ if platform.isDarwin then 11
       else if platform.isFreeBSD then 12
       else if platform.isAndroid then 12
-      else if platform.isLinux then 11
+      else if platform.isLinux then 16
       else if platform.isWasm then 12
       else 14;
     # We take the "max of the mins". Why? Since those are lower bounds of the
@@ -16672,10 +16672,10 @@ with pkgs;
     # assumption is that or any later version is good.
     choose = platform:
-      /**/ if platform.isDarwin then 11
+      /**/ if platform.isDarwin then 16
       else if platform.isFreeBSD then 12
       else if platform.isAndroid then 12